## Do not extract untrusted zip archives

### Summary

Zip Slip is a widespread critical archive extraction vulnerability, 
allowing attackers to write arbitrary files on the system.

### Details

The vulnerability is exploited using a specially crafted archive that holds directory traversal filenames (e.g. ../../evil.sh).
The Zip Slip vulnerability can affect numerous archive formats, including tar, jar, war, cpio, apk, rar and 7z.

#### Programming Languages

##### C# / .NET

Always check the `ZipArchiveEntry.FullName` property for usage of directory stepping characters `..\`

```csharp
  using (ZipArchive archive = ZipFile.OpenRead(zipPath))
  {
      foreach (ZipArchiveEntry entry in archive.Entries)
      {
          if (entry.FullName.EndsWith(".txt", StringComparison.OrdinalIgnoreCase))
          {
              entry.ExtractToFile(Path.Combine(extractPath, entry.FullName));
          }
      }
  } 
```

Validation code:

```csharp
    string destFileName = Path.GetFullPath(Path.Combine(destDirectory, entry.FullName));
    string fullDestDirPath = Path.GetFullPath(destDirectory);
    if (!destFileName.StartsWith(fullDestDirPath))
    {
        throw new Exception("Entry is outside of the target dir: " + destFileName);
    }   
```


### References

* [https://github.com/snyk/zip-slip-vulnerability](https://github.com/snyk/zip-slip-vulnerability)
